<?php

use think\migration\Migrator;
use think\migration\db\Column;
use Phinx\Db\Adapter\MysqlAdapter;

class Stations extends Migrator
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $table = $this->table('stations', ['engine' => 'InnoDB', 'collation' => 'utf8mb4_general_ci', 'comment' => '' ,'id' => 'id','signed' => true ,'primary_key' => ['id']]);
        $table->addColumn('mac', 'string', ['limit' => 20,'null' => true,'signed' => true,'comment' => '基站Mac',])
			->addColumn('shortcode', 'string', ['limit' => 20,'null' => true,'signed' => true,'comment' => '基站简码',])
			->addColumn('name', 'string', ['limit' => 50,'null' => true,'signed' => true,'comment' => '基站名称',])
			->addColumn('model', 'string', ['limit' => 50,'null' => true,'signed' => true,'comment' => '基站型号',])
			->addColumn('serial_number', 'string', ['limit' => 50,'null' => true,'signed' => true,'comment' => '基站序列号',])
			->addColumn('department_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => true,'comment' => '所属部门',])
			->addColumn('version', 'string', ['limit' => 50,'null' => true,'signed' => true,'comment' => '版本号',])
			->addColumn('open_status', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => true,'comment' => '开局状态',])
			->addColumn('sim_no', 'string', ['limit' => 50,'null' => true,'signed' => true,'comment' => 'SIM卡号',])
			->addColumn('longitude', 'decimal', ['precision' => 10,'scale' => 0,'null' => true,'signed' => true,'comment' => '经度',])
			->addColumn('latitude', 'decimal', ['precision' => 10,'scale' => 0,'null' => true,'signed' => true,'comment' => '纬度',])
			->addColumn('online_time', 'datetime', ['null' => true,'signed' => true,'comment' => '在线时间',])
			->addColumn('address', 'string', ['limit' => 200,'null' => true,'signed' => true,'comment' => '安装地址',])
			->addColumn('remark', 'text', ['limit' => MysqlAdapter::TEXT_REGULAR,'null' => true,'signed' => true,'comment' => '备注',])
			->addColumn('open_time', 'datetime', ['null' => true,'signed' => true,'comment' => '开局时间',])
			->addColumn('open_user_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => true,'signed' => true,'comment' => '开局用户',])
			->addColumn('creator_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '创建人ID',])
			->addColumn('created_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '创建时间',])
			->addColumn('updated_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '更新时间',])
			->addColumn('deleted_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '软删除',])
            ->create();
    }
}
